@@ -20,7 +20,7 @@
 #define __ORZ_CHARSET_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 #include "misc/charuty.h"
 
 
