@@ -1,6 +1,6 @@
 /*
     orzmdi
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #define __ORZ_MDI_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 
 
 #ifdef __cplusplus
@@ -102,8 +102,12 @@ orz_mdi_new (void);
       created,TRUE:新規作成,FALSE:既存ファイル
     page_data,ページデータ
           RET,ページ(0...,-1:エラー)                                        */
-#define orz_mdi_append_page(mdi,child,file,created,page_data)               \
-            orz_mdi_insert_page_menu(mdi,child,NULL,-1,file,created,page_data)
+gint
+orz_mdi_append_page (OrzMdi         *mdi,
+                     GtkWidget      *child,
+                     const gchar    *file,
+                     const gboolean  created,
+                     gpointer        page_data);
 
 
 /*  ja:ページを最後に追加する
@@ -114,8 +118,13 @@ orz_mdi_new (void);
       created,TRUE:新規作成,FALSE:既存ファイル
     page_data,ページデータ
           RET,ページ(0...,-1:エラー)                                        */
-#define orz_mdi_append_page_menu(mdi,child,menu,file,created,page_data)     \
-            orz_mdi_insert_page_menu(mdi,child,menu,-1,file,created,page_data)
+gint
+orz_mdi_append_page_menu (OrzMdi         *mdi,
+                          GtkWidget      *child,
+                          GtkWidget      *menu,
+                          const gchar    *file,
+                          const gboolean  created,
+                          gpointer        page_data);
 
 
 /*  ja:ページを最初に追加する
@@ -125,8 +134,12 @@ orz_mdi_new (void);
       created,TRUE:新規作成,FALSE:既存ファイル
     page_data,ページデータ
           RET,ページ(0...,-1:エラー)                                        */
-#define orz_mdi_prepend_page(mdi,child,file,created,page_data)              \
-            orz_mdi_insert_page_menu(mdi,child,NULL,0,file,created,page_data)
+gint
+orz_mdi_prepend_page (OrzMdi         *mdi,
+                      GtkWidget      *child,
+                      const gchar    *file,
+                      const gboolean  created,
+                      gpointer        page_data);
 
 
 /*  ja:ページを最初に追加する
@@ -137,8 +150,13 @@ orz_mdi_new (void);
       created,TRUE:新規作成,FALSE:既存ファイル
     page_data,ページデータ
           RET,ページ(0...,-1:エラー)                                        */
-#define orz_mdi_prepend_page_menu(mdi,child,menu,file,created,page_data)    \
-            orz_mdi_insert_page_menu(mdi,child,menu,0,file,created,page_data)
+gint
+orz_mdi_prepend_page_menu (OrzMdi         *mdi,
+                           GtkWidget      *child,
+                           GtkWidget      *menu,
+                           const gchar    *file,
+                           const gboolean  created,
+                           gpointer        page_data);
 
 
 /*  ja:ページを挿入する
@@ -149,8 +167,13 @@ orz_mdi_new (void);
       created,TRUE:新規作成,FALSE:既存ファイル
     page_data,ページデータ
        RET,ページ(0...,-1:エラー)                                           */
-#define orz_mdi_insert_page(mdi,child,position,file,created,page_data)      \
-    orz_mdi_insert_page_menu(mdi,child,NULL,position,file,created,page_data)
+gint
+orz_mdi_insert_page (OrzMdi         *mdi,
+                     GtkWidget      *child,
+                     const gint      position,
+                     const gchar    *file,
+                     const gboolean  created,
+                     gpointer        page_data);
 
 
 /*  ja:ページを挿入する
@@ -175,12 +198,8 @@ orz_mdi_insert_page_menu (OrzMdi         *mdi,
 /*  ja:ページ数を取得する
     mdi,ウィジェット
     RET,ページ数                                                            */
-#if GTK_CHECK_VERSION(2,2,0)
-# define orz_mdi_get_n_pages(mdi) gtk_notebook_get_n_pages(GTK_NOTEBOOK(mdi))
-#else /* not GTK_CHECK_VERSION(2,2,0) */
 gint
 orz_mdi_get_n_pages (OrzMdi *mdi);
-#endif /* not GTK_CHECK_VERSION(2,2,0) */
 
 
 /*  ja:ページをデータから取得する
