@@ -654,7 +654,7 @@ command_reload (GtkWidget *widget,
                                                                 tmaid->top.y);
       set_menu_bar (tmaid);
       draw_caret (tmaid, NULL);
-      gtk_widget_draw (tmaid->drawing, NULL);
+      gtk_widget_queue_draw (tmaid->drawing);
       charlist_renewal_all (tmaid->ft.charset, tmaid->ft.ft_id);
     }
   g_free (text);
@@ -950,7 +950,7 @@ command_all (GtkWidget *widget,
     misc_set_scroll_bar(tmaid->vscroll,
                         G_CALLBACK (signal_value_changed_vscroll), tmaid,
                         0, tmaid->max, sy, tmaid->top.y);
-  gtk_widget_draw (tmaid->drawing, NULL);
+  gtk_widget_queue_draw (tmaid->drawing);
 }
 
 
