@@ -131,7 +131,7 @@ property_change (TmaidWindow *tmaid,
                             G_CALLBACK (signal_value_changed_vscroll), tmaid,
                                             0, tmaid->max, sy, tmaid->top.y);
   /* ja:再描画 */
-  gtk_widget_draw (tmaid->drawing, NULL);
+  gtk_widget_queue_draw (tmaid->drawing);
   draw_caret (tmaid, NULL);
 }
 
@@ -265,7 +265,6 @@ property_dialog_clicked_color (GtkWidget      *widget,
                                PropertyDialog *propdlg)
 {
   gint i;
-  gdouble color[4];
   GtkListStore *store;
   GtkTreeIter iter;
   GtkWidget *dialog;
@@ -281,20 +280,18 @@ property_dialog_clicked_color (GtkWidget      *widget,
                 (gtk_tree_view_get_selection (GTK_TREE_VIEW (propdlg->tview)),
                                                                         &iter))
       {
-        color[0] = (gdouble)propdlg->gdk_color[i].red / 0xffff;
-        color[1] = (gdouble)propdlg->gdk_color[i].green / 0xffff;
-        color[2] = (gdouble)propdlg->gdk_color[i].blue / 0xffff;
-        color[3] = 0;
-        gtk_color_selection_set_color (GTK_COLOR_SELECTION
-                    (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), color);
+        gtk_color_selection_set_current_color (GTK_COLOR_SELECTION
+                            (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel),
+                                                    propdlg->gdk_color + i);
         break;
       }
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
     {
       gchar *xpm[18];
+      GdkColor color;
 
-      gtk_color_selection_get_color (GTK_COLOR_SELECTION
-                    (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), color);
+      gtk_color_selection_get_current_color (GTK_COLOR_SELECTION
+                    (GTK_COLOR_SELECTION_DIALOG (dialog)->colorsel), &color);
       xpm[0] = "24 16 1 1";
       for (i = 2; i < 18; i++)
         xpm[i] = "XXXXXXXXXXXXXXXXXXXXXXXX";
@@ -305,9 +302,9 @@ property_dialog_clicked_color (GtkWidget      *widget,
                 (gtk_tree_view_get_selection (GTK_TREE_VIEW (propdlg->tview)),
                                                                         &iter))
           {
-            propdlg->gdk_color[i].red = color[0] * 0xffff;
-            propdlg->gdk_color[i].green = color[1] * 0xffff;
-            propdlg->gdk_color[i].blue = color[2] * 0xffff;
+            propdlg->gdk_color[i].red = color.red;
+            propdlg->gdk_color[i].green = color.green;
+            propdlg->gdk_color[i].blue = color.blue;
             xpm[1] = g_strdup_printf ("X\tc #%02X%02X%02X",
                                             propdlg->gdk_color[i].red / 256,
                                             propdlg->gdk_color[i].green / 256,
@@ -752,8 +749,8 @@ property_dialog (GtkWindow *parent,
   propdlg.label = NULL;
   if (ft->text && ft->ext)
     {
-      propdlg.entry_text = gtk_entry_new_with_max_length (256);
-      propdlg.entry_ext = gtk_entry_new_with_max_length (256);
+      propdlg.entry_text = gtk_entry_new ();
+      propdlg.entry_ext = gtk_entry_new ();
       gtk_entry_set_text (GTK_ENTRY (propdlg.entry_text), ft->text);
       gtk_entry_set_text (GTK_ENTRY (propdlg.entry_ext), ft->ext);
       g_signal_connect (G_OBJECT (propdlg.entry_text), "changed",
