@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #define __TMAID_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 #include "misc/misc.h"
 
 
@@ -30,7 +30,7 @@ extern "C" {
 
 
 #define TMAID_VERSION_NOTICE "Text maid "VERSION" ("BUILD_ENVIRONMENT")"
-#define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2006 Kazuki IWAMOTO"
+#define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2007 Kazuki IWAMOTO"
 
 
 typedef struct _FileType
