@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -99,7 +99,7 @@ valchr_dialog (gunichar *valchr)
   g_signal_connect (G_OBJECT (dialog), "key-press-event",
                                     G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:エントリー */
-  entry = gtk_entry_new_with_max_length (12);
+  entry = gtk_entry_new ();
   text = misc_str_from_val (valchr_default, valchr_base, 0, FALSE);
   gtk_entry_set_text (GTK_ENTRY (entry), text);
   g_free (text);
