@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
+#include "icons.h"
 #include "version.h"
 #include "misc/gnugpl.h"
 
@@ -26,18 +26,6 @@
 * バージョン情報関数群                                                        *
 *                                                                             *
 ******************************************************************************/
-/* ESCが押された */
-static gboolean
-version_dialog_key_press (GtkWidget   *widget,
-                          GdkEventKey *event,
-                          gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:バージョン表示                                                       */
 void
 version_dialog (void)
@@ -48,65 +36,19 @@ version_dialog (void)
   GtkWidget *dialog, *notebook, *hbox0, *hbox1, *vbox;
   GtkWidget *text, *scroll;
 const static gchar *authors =
-"Main Program :\n"
-"    Kazuki IWAMOTO\n"
-"Document :\n"
+"Supreme Programmer:\n"
+" Kazuki IWAMOTO <iwm@maid.org>\n"
 "\n"
-"Logo :\n"
+"Icons Author:\n"
+" from GTK+ Stock Icons\n"
 "\n"
-"Translate :\n"
+"Packager:\n"
+" yasuo-s\n"
 "\n"
-"Packager :\n"
-"    yasuo-s\n"
-"Special Thanks :\n"
-"    Takuro Ashie\n"
-"    Koji SHIMIZU(21)\n"
-"    And all Text maid users";
-const static gchar *tmaid_xpm[] = {
-"32 32 11 1",
-"   c None",
-"+  c #000000",
-"@  c #FF0000",
-"#  c #FFFF00",
-"$  c #008000",
-"%  c #F304F3",
-"&  c #F30404",
-"*  c #0404F3",
-"=  c #04F7F3",
-"-  c #F3F704",
-";  c #04F704",
-"               +                ",
-"              +++               ",
-"             +++++              ",
-"            +++++++             ",
-"           +@#@#@#@+            ",
-"          +@#@#@#@#@+           ",
-"         +@#@#@#@#@#@+          ",
-"        +@#@#@#@#@#@#@+         ",
-"       +@#@#@#@#@#@#@#@+        ",
-"      +@#@#@#@#@#@#@#@#@+       ",
-"     +@#@#@#@#@#@#@#@#@#@+      ",
-"    +@#@#@#+++#@#@#@#@#@+++     ",
-"   +@#@#@#+$$$+#@#@#@#@+$$$+    ",
-"  +@#@#@#+$$$$$+#@#@#@+$$$$$+   ",
-"  ++@#@#+$$$$$$$+#@#@++$$$$$+   ",
-"  +$+@#++$$$$$$%$+#@+$+$$$$$+   ",
-"  +$$++$+$$$$$%%$$++$$+$$$$$+   ",
-"  +$$$$$+$$$$%%%$$$$$$+$$$$$+   ",
-"  +$$$$$+$$$$%%%$$$$$$+$$$$$+   ",
-"  +$$$$$+&$$%%%%******+$$$$$+   ",
-"  +$$$$$+&&&%%%%****$$+$$$$$+   ",
-"  +$$$$$+$&&&&%%***=$$+$$$$$+   ",
-"  +$$$$$+$&&&&&%*===$$+$$$$$+   ",
-"  +$$$$$+$$&&&-;=====$+$$$$$+   ",
-"  +$$$$$+$$&---;;====$+$$$$$+   ",
-"  +$$$$$+$-----;;;;===+$$$$$+   ",
-"  +$$$$$+------;;;;$$=+$$$$$+   ",
-"  +$$$$$+$$$$$$;;;$$$$+$$$$$+   ",
-"  +$$$$$+$$$$$$;;;$$$$+$$$$$+   ",
-"  +$$$$$+$$$$$$;;$$$$$+$$$$$+   ",
-"  +$$$$$+$$$$$$;$$$$$$+$$$$$+   ",
-"  +$$$$$+$$$$$$$$$$$$$+$$$$$+   "};
+"Special Thanks:\n"
+" Koji SHIMIZU(21)\n"
+" Takuro Ashie\n"
+" And all Text maid users";
 
   /* ja:メインウインドウ */
   dialog = gtk_dialog_new_with_buttons
@@ -119,7 +61,7 @@ const static gchar *tmaid_xpm[] = {
   gtk_window_set_default_size (GTK_WINDOW (dialog),
                     gdk_screen_width () * 2 / 3, gdk_screen_height () * 2 / 3);
   g_signal_connect (G_OBJECT (dialog), "key-press-event",
-                                G_CALLBACK (version_dialog_key_press), NULL);
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ノートブック */
   notebook = gtk_notebook_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
@@ -157,13 +99,13 @@ const static gchar *tmaid_xpm[] = {
   gtk_container_add (GTK_CONTAINER (scroll), text);
   /* ja:ノートブック */
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), scroll,
-                                                gtk_label_new (_("Authors")));
+                                gtk_label_new (_("Authors & Contributors")));
 
   /* ja:フレームとボックス */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   hbox0 = gtk_hbox_new (FALSE, SPACING);
-  pixbuf = gdk_pixbuf_new_from_xpm_data (tmaid_xpm);
+  pixbuf = gdk_pixbuf_new_from_xpm_data (tmaid32_xpm);
   gtk_box_pack_start (GTK_BOX (hbox0),
                         gtk_image_new_from_pixbuf (pixbuf), FALSE, FALSE, 0);
   g_object_unref (pixbuf);
